@@ -1,16 +1,24 @@
 <?php
+
+if(!defined('CONFIG_CHECK')) define('CONFIG_CHECK', TRUE);
+if(!defined('CONFIG_CHECK_COOKIES_HTTP')) define('CONFIG_CHECK_COOKIES_HTTP', FALSE);
+if(!defined('CONFIG_CHECK_COOKIES_SSL')) define('CONFIG_CHECK_COOKIES_SSL', FALSE);
+
 /**
  * This file is used to set configuration options to a default value that have 
  * not been set in the config.php.Each definition of a configuration value must 
  * be preceeded by "if(!defined('KEY'))"
  */
-
-if(!defined('DEBUG_LOADER')) define('DEBUG_LOADER', LOAD_RELEASE);
-
+if(!defined('STATE_FILE_MAX_LIFETIME')) define('STATE_FILE_MAX_LIFETIME', 28*60*60);
 if(!defined('UPLOADED_ATTACHMENT_MAX_LIFETIME')) define('UPLOADED_ATTACHMENT_MAX_LIFETIME', 6*60*60);
 if(!defined('DISABLE_FULL_CONTACTLIST_THRESHOLD')) define('DISABLE_FULL_CONTACTLIST_THRESHOLD', -1);
 if(!defined('ENABLE_PUBLIC_FOLDERS')) define('ENABLE_PUBLIC_FOLDERS', true);
 
+/**
+ * When set to true, we enable GZIP
+ */
+if(!defined('ENABLE_RESPONSE_COMPRESSION')) define('ENABLE_RESPONSE_COMPRESSION', true);
+
 /**
  * When set to true this disables the fitlering of the HTML body.
  */
@@ -42,5 +50,17 @@ if(!defined('ENABLE_DIRECT_BOOKING')) define('ENABLE_DIRECT_BOOKING', true);
 if(!defined('ENABLED_LANGUAGES')) define("ENABLED_LANGUAGES", "de_DE;en_GB;en_US;es_ES;fi_FI;fr_FR;he_IL;hu_HU;it_IT;nb_NO;nl_NL;pl_PL;pt_BR;ru_RU;zh_CN");
 
 if(!defined('ENABLE_PLUGINS')) define('ENABLE_PLUGINS', true);
+if(!defined('PATH_PLUGIN_CONFIG_DIR')) define('PATH_PLUGIN_CONFIG_DIR', PATH_PLUGIN_DIR);
 
+/*
+ * The following options are taken from the debug.php
+ */
+if(!defined('DEBUG_LOADER')) define('DEBUG_LOADER', LOAD_RELEASE);
+if(!defined('DEBUG_XMLOUT')) define('DEBUG_XMLOUT', false);
+if(!defined('DEBUG_XMLOUT_DIR')) define('DEBUG_XMLOUT_DIR', 'debug_xml/');
+if(!defined('DEBUG_XMLOUT_GZIP')) define('DEBUG_XMLOUT_GZIP', false);
+if(!defined('DEBUG_PLUGINS')) define('DEBUG_PLUGINS', false);
+if(!defined('DEBUG_PLUGINS_DISABLE_CACHE')) define('DEBUG_PLUGINS_DISABLE_CACHE', false);
+if(!defined('DEBUG_DUMP_FILE')) define('DEBUG_DUMP_FILE', 'debug.txt');
+if(!defined('DEBUG_SHOW_SERVER')) define('DEBUG_SHOW_SERVER', false);
 ?>
