@@ -55,6 +55,7 @@
 	include("server/core/class.properties.php");
 
 	require("server/core/class.state.php");
+	require("server/core/class.attachmentstate.php");
 
 	require("server/core/class.pluginmanager.php");
 	require("server/core/class.plugin.php");
@@ -68,7 +69,7 @@
 		}
 		session_destroy();
 
-		header("Refresh: 0; url=index.php");
+		header("Location: index.php", true, 303);
 		exit;
 	}
 
@@ -146,55 +147,24 @@
 		$GLOBALS["language"]->setLanguage($lang);
 		if($_GET && array_key_exists("logon", $_GET)) {
 			$GLOBALS['PluginManager']->triggerHook("server.index.login.success");
-			if(isset($_POST) && isset($_POST["action_url"]) && !empty($_POST["action_url"])) {
-				// if action attributes are passed in POST variable then append it to URL for
-				// further processing
-				$url = "index.php" . $_POST["action_url"];
-				header("Refresh: 0; url=$url");
-				exit;
-			} else {
-				header("Refresh: 0; url=index.php");
-				exit;
-			}
+			header("Location: index.php", true, 303);
+			exit;
 		}
 
 		// add extra header
-		header("X-Zarafa: ".phpversion("mapi").(defined("SVN") ? "-".SVN:""));
+		header("X-Zarafa: " . trim(file_get_contents('version')));
 
 		// external files who need our login
 		if ($_GET && array_key_exists("load", $_GET)) {
 
-			// Get Attachment data from state and put it into the $_SESSION
-			$attachment_state = new State('attachments');
-			$attachment_state->open();
-			$_SESSION['files'] = $attachment_state->read("files");
-			$_SESSION['deleteattachment'] = $attachment_state->read("deleteattachment");
-			$attachment_state->close();
 			switch ($_GET["load"]) {
 				case "translations.js":
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.jstranslations.before");
 					include("client/translations.js.php");
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.jstranslations.after");
 					break;
-				case "dialog":
-					// If the dialog is called with attachid in URL we want to call the upload attachment file 
-					// first to upload the files to the server, and add them to session files.
-					if($_GET && array_key_exists("attachment_id", $_GET)){
-						$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.before");
-						include("server/upload_attachment.php");
-						$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.after");
-						// Get Attachment data from $_SESSION and put it into the state
-						// Do it now before outputting the webclient.php data, so that zarafa.php cannot be called
-						// before we have written the data
-						$attachment_state = new State('attachments');
-						$attachment_state->open();
-						$attachment_state->write("files", $_SESSION['files']);
-						$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
-						$attachment_state->close();
-					}
-					$GLOBALS['PluginManager']->triggerHook("server.index.load.dialog.before");
-					include("client/webclient.php");
-					$GLOBALS['PluginManager']->triggerHook("server.index.load.dialog.after");
+				case "custom":
+					$GLOBALS['PluginManager']->triggerHook("server.index.load.custom", array('name' => $_GET['name']));
 					break;
 				case "upload_attachment":
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.before");
@@ -218,15 +188,29 @@
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.main.after");
 					break;
 			}
-
-			// Get Attachment data from $_SESSION and put it into the state
-			$attachment_state = new State('attachments');
-			$attachment_state->open();
-			$attachment_state->write("files", $_SESSION['files']);
-			$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
-			$attachment_state->close();
-			// Prevent the SESSION data to be stored elsewhere
-			unset($_SESSION['files'], $_SESSION['deleteattachment']);
+		} else if ($_GET && array_key_exists("authenticate", $_GET)) {
+			$version = trim(file_get_contents('version'));
+			$data = array(
+				"settings" => $GLOBALS["settings"]->getJSON(),
+				"properties" => $GLOBALS["properties"]->getJSON(),
+				"languages" => $GLOBALS["language"]->getJSON(),
+				"user" => array(
+					"username" 	=> addslashes($GLOBALS["mapisession"]->getUserName()),
+					"fullname" 	=> addslashes($GLOBALS["mapisession"]->getFullName()),
+					"entryid" 	=> bin2hex($GLOBALS["mapisession"]->getUserEntryid()),
+					"email_address" => addslashes($GLOBALS["mapisession"]->getEmailAddress()),
+					"smtp_address" 	=> addslashes($GLOBALS["mapisession"]->getSMTPAddress()),
+					"search_key" 	=> bin2hex($GLOBALS["mapisession"]->getSearchKey()),
+					"sessionid" 	=> session_id()
+				),
+				"version" => array(
+					"webapp"	=> $version,
+					"zcp"		=> phpversion('mapi'),
+					"server"	=> DEBUG_SHOW_SERVER ? DEBUG_SERVER_ADDRESS : '',
+					"svn"		=> DEBUG_LOADER === LOAD_SOURCE ? svnversion() : ''
+				)
+			);
+			echo JSON::Encode(array("zarafa" => $data));
 		} else if ($_GET && array_key_exists("verify", $_GET)) {
 			
 			$user = $_GET["verify"];
@@ -241,9 +225,10 @@
 			$state = new State("index");
 			$state->clean();
 
-			// Clean up old attachments in tmp
-			cleanTemp(TMP_PATH, UPLOADED_ATTACHMENT_MAX_LIFETIME);
-					
+			// Clean up old attachments in tmp/attachments/
+			$state = new AttachmentState();
+			$state->clean();
+
 			// clean search folders
 			cleanSearchFolders();
 
@@ -253,6 +238,10 @@
 			include("client/webclient.php");
 			$GLOBALS['PluginManager']->triggerHook("server.index.load.main.after");
 		}
+
+		// Save the settings to the MAPI store
+		$GLOBALS['settings']->saveSettings();
+
 	} else { // Not authenticated, goto login page
 		// Create global language object
 		$GLOBALS["language"] = new Language();
