@@ -248,7 +248,13 @@ class Services_JSON
 
             case 'double':
             case 'float':
-                return (float) $var;
+                /**
+                 * Please refer to https://bugs.php.net/bug.php?id=40360, in PHP < 5.2.1
+                 * (string) 5.2 would under some locales (e.g. de_DE, nl_NL, ru_RU) be converted
+                 * to the string "5,2" which is an invalid JSON value. To fix this we have
+                 * to convert the string to replace all ',' characters with the '.'.
+                 */
+                return str_replace(',', '.', (string) $var);
 
             case 'string':
                 // STRINGS ARE EXPECTED TO BE IN ASCII OR UTF-8 FORMAT
@@ -824,4 +830,4 @@ if( !function_exists('json_decode') ) {
 		return $json->decode($data);
 	}
 }
-?>
\ No newline at end of file
+?>
