@@ -35,12 +35,12 @@
 		/**
 		 * @var object MAPI Message Store object
 		 */
-		var $store;
+		var $store = false;
 
 		/**
 		 * @var string The PR_MAPPING_SIGNATURE for the current store
 		 */
-		var $storeMapping;
+		var $storeMapping = false;
 
 		/**
 		 * @var TRUE if we have init'ed, FALSE if not
@@ -70,12 +70,14 @@
 				return;
 			} else {
 				$this->store = $GLOBALS["mapisession"]->getDefaultMessageStore();
-				$this->storeMapping = mapi_getprops($this->store, array(PR_MAPPING_SIGNATURE));
-				$this->storeMapping = isset($this->storeMapping[PR_MAPPING_SIGNATURE]) ? bin2hex($this->storeMapping[PR_MAPPING_SIGNATURE]) : '0';
+				if (!$this->storeMapping) {
+					$this->storeMapping = mapi_getprops($this->store, array(PR_MAPPING_SIGNATURE));
+					$this->storeMapping = isset($this->storeMapping[PR_MAPPING_SIGNATURE]) ? bin2hex($this->storeMapping[PR_MAPPING_SIGNATURE]) : '0';
 
-				// Ensure the mapping exists
-				if (!isset($this->mapping[$this->storeMapping])) {
-					$this->mapping[$this->storeMapping] = array();
+					// Ensure the mapping exists
+					if (!isset($this->mapping[$this->storeMapping])) {
+						$this->mapping[$this->storeMapping] = array();
+					}
 				}
 
 				$this->init = true;
@@ -95,15 +97,15 @@
 			$this->init = false;
 			$this->store = false;
 			$this->storeMapping = false;
+			$this->mapping = array();
 		}
 
 		/**
 		 * Function will retrieve all the properties for all the loaded stores in mapisession
-		 * and will create a javascript array object to send it to client side.
-		 * @param String $base variable name to use for dumping this data to javascript.
+		 * and will create a json array object to send it to client side.
 		 * @return String json encoded php array for all properties.
 		 */
-		function getProperties($base = "properties")
+		function getJSON()
 		{
 			$this->Init();
 
@@ -135,7 +137,7 @@
 
 			// @TODO this implementation should be extended to add more named properties by plugins also
 
-			return $base . ' = ' . JSON::Encode($output) . ';';
+			return $output;
 		}
 
 		/**
@@ -149,6 +151,7 @@
 			if (!isset($this->mapping[$this->storeMapping]['recipient'])) {
 				$properties = array();
 				$properties["entryid"] = PR_ENTRYID;
+				$properties["search_key"] = PR_SEARCH_KEY;
 				$properties["rowid"] = PR_ROWID;
 				$properties["display_name"] = PR_DISPLAY_NAME;
 				$properties["display_type"] = PR_DISPLAY_TYPE;
@@ -191,7 +194,8 @@
 				$properties["meetingstatus"] = "PT_LONG:PSETID_Appointment:0x8217";
 				$properties["responsestatus"] = "PT_LONG:PSETID_Appointment:0x8218";
 				$properties["unknown6"] = "PT_LONG:PSETID_Meeting:0x4";
-				$properties["replytime"] = "PT_SYSTIME:PSETID_Appointment:0x8220";
+				$properties["reply_time"] = "PT_SYSTIME:PSETID_Appointment:0x8220";
+				$properties["reply_name"] = "PT_STRING8:PSETID_Appointment:0x8230";
 				$properties["usetnef"] = "PT_BOOLEAN:PSETID_Common:0x8582";
 				$properties["recurrence_data"] = "PT_BINARY:PSETID_Appointment:0x8216";
 				$properties["reminderminutes"] = "PT_LONG:PSETID_Common:0x8501";
@@ -218,7 +222,6 @@
 				$properties["end_recur_date"] = "PT_LONG:PSETID_Meeting:0xF";                           // EndRecurDate
 				$properties["end_recur_time"] = "PT_LONG:PSETID_Meeting:0x10";                          // EndRecurTime
 				$properties["is_exception"] = "PT_BOOLEAN:PSETID_Meeting:0xA";                          // LID_IS_EXCEPTION
-				$properties["apptreplyname"] = "PT_STRING8:PSETID_Appointment:0x8230";
 				// Propose new time properties
 				$properties["proposed_start_whole"] = "PT_SYSTIME:PSETID_Appointment:0x8250";
 				$properties["proposed_end_whole"] = "PT_SYSTIME:PSETID_Appointment:0x8251";
@@ -239,7 +242,7 @@
 		}
 
 		/**
-		 * Returns the properties for an appointment.
+		 * Returns the properties for an appointment which is opened in a dialog.
 		 * @return array properties for an appointment.		 
 		 */
 		function getAppointmentProperties()
@@ -316,15 +319,26 @@
 
 				$properties["deleted_on"] = PR_DELETED_ON;
 				$properties["updatecounter"] = "PT_LONG:PSETID_Appointment:0x8201";
-				$properties["recurrencetype"] = "PT_LONG:PSETID_Appointment:0x8231";
 				$properties["reply_time"] = "PT_SYSTIME:PSETID_Appointment:0x8220";
-				$properties["side_effects"] = "PT_LONG:PSETID_Common:0x8510";
+				$properties["reply_name"] = "PT_STRING8:PSETID_Appointment:0x8230";
 
 				$this->mapping[$this->storeMapping]['appointment'] = getPropIdsFromStrings($this->store, $properties);
 			}
 
 			return $this->mapping[$this->storeMapping]['appointment'];
 		}
+
+		/**
+		 * Returns the properties for an appointment in the listview.
+		 * @return array properties for an appointment.		 
+		 */
+		function getAppointmentListProperties()
+		{
+			$properties = $this->getAppointmentProperties();
+
+			return $properties;
+		}
+
 		/**
 		 * Returns the minimal set of properties for an appointment (similar to freebusy data)
 		 * @return array minimal properties for an appointment.
@@ -346,7 +360,7 @@
 		}
 
 		/**
-		 * Returns the properties for a contact.
+		 * Returns the properties for a contact when opened in a dialog.
 		 * @return array properties for a contact.
 		 */
 		function getContactProperties()
@@ -488,11 +502,70 @@
 			return $this->mapping[$this->storeMapping]['contact'];
 		}
 
+		/**
+		 * Returns the properties for a contact in the listview.
+		 * @return array properties for a contact.
+		 */
+		function getContactListProperties()
+		{
+			$properties = $this->getContactProperties();
+
+			unset($properties['members']);
+			unset($properties['oneoff_members']);
+
+			unset($properties['email_address_entryid_1']);
+			unset($properties['email_address_display_name_1']);
+			unset($properties['email_address_display_name_email_1']);
+			unset($properties['email_address_type_1']);
+			unset($properties['email_address_entryid_2']);
+			unset($properties['email_address_display_name_2']);
+			unset($properties['email_address_display_name_email_2']);
+			unset($properties['email_address_type_2']);
+			unset($properties['email_address_entryid_3']);
+			unset($properties['email_address_display_name_3']);
+			unset($properties['email_address_display_name_email_3']);
+			unset($properties['email_address_type_3']);
+
+			unset($properties['fax_1_address_type']);
+			unset($properties['fax_1_email_address']);
+			unset($properties['fax_1_original_display_name']);
+			unset($properties['fax_1_original_entryid']);
+			unset($properties['fax_2_address_type']);
+			unset($properties['fax_2_email_address']);
+			unset($properties['fax_2_original_display_name']);
+			unset($properties['fax_2_original_entryid']);
+			unset($properties['fax_3_address_type']);
+			unset($properties['fax_3_email_address']);
+			unset($properties['fax_3_original_display_name']);
+			unset($properties['fax_3_original_entryid']);
+
+			unset($properties['home_address_street']);
+			unset($properties['home_address_city']);
+			unset($properties['home_address_state']);
+			unset($properties['home_address_postal_code']);
+			unset($properties['home_address_country']);
+			unset($properties['other_address_street']);
+			unset($properties['other_address_city']);
+			unset($properties['other_address_state']);
+			unset($properties['other_address_postal_code']);
+			unset($properties['other_address_country']);
+			unset($properties['business_address_street']);
+			unset($properties['business_address_city']);
+			unset($properties['business_address_state']);
+			unset($properties['business_address_postal_code']);
+			unset($properties['business_address_country']);
+
+			unset($properties['birthday_eventid']);
+			unset($properties['anniversary_eventid']);
+
+			return $properties;
+		}
+
 		/**
 		 * Returns the properties for a contact in the addressbook.
 		 * @return array properties for a contact.
 		 */
-		function getContactABProperties()
+		function getContactABListProperties()
 		{
 			$this->Init();
 
@@ -531,7 +604,7 @@
 				$properties["oneoff_members"] = "PT_MV_BINARY:PSETID_Address:0x8054";
 				$properties["members"] = "PT_MV_BINARY:PSETID_Address:0x8055";
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
-	  			$properties["sensitivity"] = PR_SENSITIVITY;
+				$properties["sensitivity"] = PR_SENSITIVITY;
 				$properties["private"] = "PT_BOOLEAN:PSETID_Common:0x8506";
 
 				$properties["deleted_on"] = PR_DELETED_ON;
@@ -583,7 +656,7 @@
 		 * Returns the properties for a contact in the addressbook.
 		 * @return array properties for a contact.
 		 */
-		function getAddressBookProperties()
+		function getAddressBookListProperties()
 		{
 			$this->Init();
 
@@ -603,6 +676,8 @@
 				$properties["office_location"] = PR_OFFICE_LOCATION;
 				$properties["primary_fax_number"] = PR_PRIMARY_FAX_NUMBER;
 				$properties["department_name"] = PR_DEPARTMENT_NAME;
+				$properties["normalized_subject"] = PR_NORMALIZED_SUBJECT;
+				$properties["original_display_name"] = PR_ORIGINAL_DISPLAY_NAME;
 
 				$this->mapping[$this->storeMapping]['addressbook'] = getPropIdsFromStrings($this->store, $properties);
 			}
@@ -731,7 +806,7 @@
 		}
 
 		/**
-		 * Returns the properties for an email.
+		 * Returns the properties for an email when it is being opened
 		 * @return array properties for an email. 
 		 */
 		function getMailProperties()
@@ -757,14 +832,17 @@
 				$properties["sent_representing_email_address"] = PR_SENT_REPRESENTING_EMAIL_ADDRESS;
 				$properties["sent_representing_address_type"] = PR_SENT_REPRESENTING_ADDRTYPE;
 				$properties["sent_representing_entryid"] = PR_SENT_REPRESENTING_ENTRYID;
+				$properties["sent_representing_search_key"] = PR_SENT_REPRESENTING_SEARCH_KEY;
 				$properties["sender_name"] = PR_SENDER_NAME;
 				$properties["sender_email_address"] = PR_SENDER_EMAIL_ADDRESS;
 				$properties["sender_address_type"] = PR_SENDER_ADDRTYPE;
 				$properties["sender_entryid"] = PR_SENDER_ENTRYID;
+				$properties["sender_search_key"] = PR_SENDER_SEARCH_KEY;
 				$properties["received_by_name"] = PR_RECEIVED_BY_NAME;
 				$properties["received_by_email_address"] = PR_RECEIVED_BY_EMAIL_ADDRESS;
 				$properties["received_by_address_type"] = PR_RECEIVED_BY_ADDRTYPE;
 				$properties["received_by_entryid"] = PR_RECEIVED_BY_ENTRYID;
+				$properties["received_by_search_key"] = PR_RECEIVED_BY_SEARCH_KEY;
 				$properties["message_delivery_time"] = PR_MESSAGE_DELIVERY_TIME;
 				$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
 				$properties["last_verb_executed"] = PR_LAST_VERB_EXECUTED;
@@ -836,8 +914,37 @@
 		}
 
 		/**
-		 * Returns the properties for a sticky note.
-		 * @return array properties for a sticky note.		 
+		 * Returns the properties for an email in the list view.
+		 * @return array properties for an email. 
+		 */
+		function getMailListProperties()
+		{
+			$properties = $this->getMailProperties();
+
+			unset($properties['transport_message_headers']);
+			unset($properties['appointment_startdate']);
+			unset($properties['appointment_duedate']);
+			unset($properties['appointment_location']);
+			unset($properties['appointment_recurring_pattern']);
+			unset($properties['appointment_startdate_recurring']);
+			unset($properties['appointment_enddate_recurring']);
+			unset($properties['appointment_exception']);
+			unset($properties['appointment_location']);
+			unset($properties['proposed_start_date']);
+			unset($properties['proposed_end_date']);
+			unset($properties['proposed_duration']);
+			unset($properties['counter_proposal']);
+			unset($properties['responsestatus']);
+			unset($properties['meetingtype']);
+			unset($properties['goid']);
+			unset($properties['goid2']);
+
+			return $properties;
+		}
+
+		/**
+		 * Returns the properties for a sticky note when it is being opened.
+		 * @return array properties for a sticky note.
 		 */
 		function getStickyNoteProperties()
 		{
@@ -855,7 +962,6 @@
 				$properties["message_flags"] = PR_MESSAGE_FLAGS;
 				$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
 				$properties["subject"] = PR_SUBJECT;
-				$properties["body"] = PR_BODY;
 				$properties["creation_time"] = PR_CREATION_TIME;
 				$properties["color"] = "PT_LONG:PSETID_Note:0x8B00";
 				$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
@@ -871,8 +977,19 @@
 		}
 
 		/**
-		 * Returns the properties for a task.
-		 * @return array properties for a task.		 
+		 * Returns the properties for a sticky note in the list view.
+		 * @return array properties for a sticky note.
+		 */
+		function getStickyNoteListProperties()
+		{
+			$properties = $this->getStickyNoteProperties();
+
+			return $properties;
+		}
+
+		/**
+		 * Returns the properties for a task when it is being opened.
+		 * @return array properties for a task.
 		 */
 		function getTaskProperties()
 		{
@@ -903,7 +1020,6 @@
 				$properties["reminder_time"] = "PT_SYSTIME:PSETID_Common:0x8502";
 				$properties["reminder"] = "PT_BOOLEAN:PSETID_Common:0x8503";
 				$properties["reset_reminder"] = "PT_BOOLEAN:PSETID_Task:0x8107";
-				$properties["side_effects"] = "PT_LONG:PSETID_Common:0x8510";
 				$properties["date_completed"] = "PT_SYSTIME:PSETID_Task:0x810f";
 				$properties["totalwork"] = "PT_LONG:PSETID_Task:0x8111";
 				$properties["actualwork"] = "PT_LONG:PSETID_Task:0x8110";
@@ -961,6 +1077,17 @@
 			return $this->mapping[$this->storeMapping]['task'];
 		}
 
+		/**
+		 * Returns the properties for a task in the listview.
+		 * @return array properties for a task.		 
+		 */
+		function getTaskListProperties()
+		{
+			$properties = $this->getTaskProperties();
+
+			return $properties;
+		}
+
 		/**
 		 * Returns the properties used by the "properties" dialog.
 		 * @return array properties.
@@ -995,6 +1122,22 @@
 			return $this->mapping[$this->storeMapping]['folder'];
 		}
 
+		/**
+		 * Returns the properties used by the hierarchy to show the folders.
+		 * @return Array properties.
+		 */
+		function getFolderListProperties()
+		{
+			$properties = $this->getFolderProperties();
+
+			unset($properties['comment']);
+			unset($properties['message_size']);
+			unset($properties['deleted_on']);
+			unset($properties['creation_time']);
+
+			return $properties;
+		}
+
 		/**
 		 * Returns the properties used for the reminders dialog
 		 * @return array properties
