@@ -11,10 +11,9 @@
 		 */
 		function AddressbookListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getContactABProperties();
-			$this->ab_properties = $GLOBALS["properties"]->getAddressBookProperties();
-		
-			parent::ListModule($id, $data, array());
+			$this->properties = $GLOBALS['properties']->getAddressBookListProperties();
+
+			parent::ListModule($id, $data);
 		}
 		
 		/**
@@ -31,27 +30,21 @@
 						$parententryid = $this->getActionParentEntryID($action);
 						$entryid = $this->getActionEntryID($action);
 
-						if(isset($action["subActionType"]) && $action["subActionType"] != "") {
-							$subActionType = $action["subActionType"];
+						if(isset($action['subActionType']) && $action['subActionType'] != '') {
+							$subActionType = $action['subActionType'];
 						}
 
 						switch($actionType)
 						{
-							case "list":
+							case 'list':
 								switch($subActionType)
 								{
-									case "hierarchy":
+									case 'hierarchy':
 										$this->getHierarchy($action);
-									break;
-
-									case "contacts":
-										$this->messageList($store, $entryid, $action, $subActionType);
-									break;
-
-									case "globaladdressbook":
+										break;
+									case 'globaladdressbook':
 										$this->GABUsers($action, $subActionType);
-									break;
-
+										break;
 									default:
 										$this->handleUnknownActionType($actionType);
 								}
@@ -60,217 +53,12 @@
 								$this->handleUnknownActionType($actionType);
 						}
 					} catch (MAPIException $e) {
-						$this->processException($e, $actionType);
+						$this->processException($e, $actionType, $store, $parententryid, $entryid, $action);
 					}
 				}
 			}
 		}
 		
-		/**
-		 * Function which retrieves a list of contacts in a contact folder
-		 * @param object $store MAPI Message Store Object
-		 * @param string $entryid entryid of the folder
-		 * @param array $action the action data, sent by the client
-		 * @param string $actionType the action type, sent by the client
-		 * @return boolean true on success or false on failure
-		 */
-		function messageList($store, $entryid, $action, $actionType)
-		{
-			$searchPerformed = false;				// flag to check the request is for search or not
-			$disableFullContactlist = false;		// flag for disabling the contact list
-
-			if(!$entryid) {
-				$rootcontainer = mapi_msgstore_openentry($store);
-				if($rootcontainer) {
-					$props = mapi_getprops($rootcontainer, array(PR_IPM_CONTACT_ENTRYID));
-					
-					if(isset($props[PR_IPM_CONTACT_ENTRYID])) {
-						$entryid = $props[PR_IPM_CONTACT_ENTRYID];
-					}
-				}
-			}
-
-			if($store && $entryid) {
-				$restriction = array(RES_AND, // get contacts when having one or more email adress
-									array(
-										array(RES_PROPERTY,
-											array(	RELOP=>RELOP_EQ,
-													ULPROPTAG=>PR_MESSAGE_CLASS,
-													VALUE => array(PR_MESSAGE_CLASS=>"IPM.Contact")
-											)
-										),
-										array(RES_PROPERTY,
-											array(	RELOP => RELOP_GT,
-													ULPROPTAG => $this->properties["address_book_long"],
-													VALUE => array($this->properties["address_book_long"] => 0)
-											)
-										)
-									)
-								);
-
-				// include distribution lists when requested
-				if (!isset($action["restriction"]["hide_distlist"]) || $action["restriction"]["hide_distlist"] !== true) {
-					$restriction = 	array(RES_OR,
-										array(
-											array(RES_PROPERTY, // get distribution lists
-												array(
-													RELOP => RELOP_EQ,
-													ULPROPTAG => PR_MESSAGE_CLASS,
-													VALUE => array( PR_MESSAGE_CLASS => "IPM.DistList" )
-												)
-											),
-											$restriction
-										)
-									);
-				}
-
-				if(isset($action["restriction"])) {
-					if(isset($action["restriction"]["searchstring"])) {
-						$searchPerformed = true;
-						$restrictions = array();
-						$props = array($this->properties["fileas"], 
-									   $this->properties["display_name"],
-									   $this->properties["email_address_1"],
-									   $this->properties["email_address_display_name_1"],
-									   $this->properties["email_address_2"],
-									   $this->properties["email_address_display_name_2"],
-									   $this->properties["email_address_3"],
-									   $this->properties["email_address_display_name_3"]);
-						
-						foreach($props as $property)
-						{
-							array_push($restrictions, array(RES_CONTENT,
-															array(FUZZYLEVEL => FL_SUBSTRING|FL_IGNORECASE,
-																ULPROPTAG => $property,
-																VALUE => $action["restriction"]["searchstring"])));
-						}
-
-						$restrictions = array(RES_OR, $restrictions);
-						$restriction = array(RES_AND, array($restriction, $restrictions));
-					} else if (isset($action["restriction"]["pagination_character"]) && $action["restriction"]["pagination_character"] != "...") {
-						// If request is for gab pagination then set pagination restriction.
-						$searchPerformed = true;
-
-						// Get pagination restriction and add it in restriction array.
-						$paginationRestriction = $this->getPaginationRestriction($action, $actionType);
-						if($paginationRestriction)
-							$restriction = array(RES_AND, array($restriction, $paginationRestriction));
- 					}
-				}
-				
-				// We map the 'email_address' column to 'email_address_1' for sorting. This is a bit of a hack
-				// because we are showing either email_address_1 or _2 or _3 ...
-				
-				$map = array();
-				$map["email_address"] = $this->properties["email_address_1"];
-				
-				$this->parseSortOrder($action, $map, true);
-
-				$data = array();
-
-				// open contacts folder
-				$folder = mapi_msgstore_openentry($store, $entryid);
-				if(mapi_last_hresult() == NOERROR) {
-					$contentsTable = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
-
-					/**
-					 * Check whether we have to disable the full contactlist listing using the config: 
-					 * DISABLE_FULL_CONTACTLIST_THRESHOLD. we are checking here if in case 
-					 * mapi_table_getrowcount returns number greater then this config value then we
-					 * don't have to do any processing, so it will lessen processing time
-					 */
-					if(DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed) {
-						if(DISABLE_FULL_CONTACTLIST_THRESHOLD >= 0 && mapi_table_getrowcount($contentsTable) > DISABLE_FULL_CONTACTLIST_THRESHOLD) {
-							$disableFullContactlist = true;
-						}
-					}
-
-					// apply restriction & sorting
-					mapi_table_restrict($contentsTable, $restriction, TBL_BATCH);
-					mapi_table_sort($contentsTable, $this->sort, TBL_BATCH);
-
-					if(!$disableFullContactlist) {
-						// Get all rows
-						/**
-						 * we can also use mapi_table_queryallrows but it internally calls queryrows with 
-						 * start as 0 and end as 0x7fffffff, so we are directly calling mapi_table_queryrows
-						 */
-						$rows = mapi_table_queryrows($contentsTable, $this->properties, 0, 0x7fffffff);
-
-						// Search for distribution lists and get all email adresses in the distribution lists.
-						$items = array();
-						foreach($rows as $row)
-						{
-							$item = Conversion::mapMAPI2XML($this->properties, $row);
-
-							if(isset($item["props"]["message_class"])) {
-								switch($item["props"]["message_class"])
-								{
-									case "IPM.Contact":
-										if(isset($item["props"]["address_book_mv"]) && is_array($item["props"]["address_book_mv"])){
-											$email_addresses = $item["props"]["address_book_mv"];
-											$entryid = $item["entryid"];
-
-											foreach($email_addresses as $email_address)
-											{
-												$email_address += 1; // address_book_mv starts with 0, so we add '1' here
-
-												if(isset($item["props"]["email_address_" . $email_address])) {
-													$item["props"]["email_address"] = $item["props"]["email_address_" . $email_address];
-													$item["props"]["display_name"] = $item["props"]["email_address_display_name_" . $email_address];
-													$item["props"]["address_type"] = $item["props"]["email_address_type_" . $email_address];
-													$item["props"]["email_index"] = $email_address;
-
-													array_push($items, $item);
-												}
-											}
-										}
-										break;
-									case "IPM.DistList":
-										$item["props"]["email_address"] = $item["props"]["display_name"];
-										$item["props"]["address_type"] = "ZARAFA";
-
-										$entryid = hex2bin($item["entryid"]); // need real entryid here
-										$item["members"] = array("item" => $GLOBALS["operations"]->getMembersFromDistributionList($store, $entryid, $this->properties));
-
-										// remove non-client props that has been expanded using above code
-										unset($item["props"]["members"]);
-										unset($item["props"]["oneoff_members"]);
-
-										array_push($items, $item);
-										break;
-								}
-							}
-						}
-
-						/**
-						 * Check whether we have to disable the full contactlist listing using the config: 
-						 * DISABLE_FULL_CONTACTLIST_THRESHOLD. We check this after we have looped through all the
-						 * items (code above) becuase it could happen then after expanding the groups the number
-						 * of rows crosses the limit. This is because we need to know how many rows the contactlist
-						 * will contain. Also note that when the user conducts a search the list should be displayed 
-						 * regardless of the number of items returned.
-						 */
-						if(DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed){
-							if(DISABLE_FULL_CONTACTLIST_THRESHOLD >= 0 && count($items) > DISABLE_FULL_CONTACTLIST_THRESHOLD){
-								$disableFullContactlist = true;
-							}
-						}
-					}
-
-					if(!$disableFullContactlist){
-						$data = array_merge($data, array("item" => $items));
-					}else{
-						// Provide clue that full contactlist is disabled.
-						$data = array_merge($data, array("disable_full_gab" => true));
-					}
-
-					$this->addActionData("list", $data);
-					$GLOBALS["bus"]->addData($this->getResponseData());
-				}
-			}
-		}
-		
 		/**
 		 * Function which retrieves the list of system users in Zarafa.
 		 * @param object $store MAPI Message Store Object
@@ -280,67 +68,65 @@
 		 */
 		function GABUsers($action, $actionType)
 		{
-			$searchstring = "";
-			$paginationCharacter = "";
+			$searchstring = '';
+			$paginationCharacter = '';
 			$hide_users = false;
 			$hide_groups = false;
 			$hide_companies = false;
-			if(isset($action["restriction"])) {
-				if(isset($action["restriction"]["searchstring"])) {
+
+			if(isset($action['restriction'])) {
+				if(isset($action['restriction']['searchstring'])) {
 					// Get search string for searching in AB.
-					$searchstring = $action["restriction"]["searchstring"];
-				} else if (isset($action["restriction"]["pagination_character"])) {
+					$searchstring = $action['restriction']['searchstring'];
+				} else if (isset($action['restriction']['pagination_character'])) {
 					// Get pagination character for AB.
-					$paginationCharacter = $action["restriction"]["pagination_character"];
+					$paginationCharacter = $action['restriction']['pagination_character'];
 				}
 
-				if(isset($action["restriction"]["hide_users"])) {
-					$hide_users = $action["restriction"]["hide_users"];
+				if(isset($action['restriction']['hide_users'])) {
+					$hide_users = $action['restriction']['hide_users'];
 				}
-				if(isset($action["restriction"]["hide_groups"])) {
-					$hide_groups = $action["restriction"]["hide_groups"];
+				if(isset($action['restriction']['hide_groups'])) {
+					$hide_groups = $action['restriction']['hide_groups'];
 				}
-				if(isset($action["restriction"]["hide_companies"])) {
-					$hide_companies = $action["restriction"]["hide_companies"];
+				if(isset($action['restriction']['hide_companies'])) {
+					$hide_companies = $action['restriction']['hide_companies'];
 				}
 			}
 
 			$items = array();
 
-			$data["page"] = array();
-			$data["page"]["start"] = 0;
-			$data["page"]["rowcount"] = 0;
-			$data["page"]["totalrowcount"] = 0;
+			$data['page'] = array();
+			$data['page']['start'] = 0;
+			$data['page']['rowcount'] = 0;
+			$data['page']['totalrowcount'] = 0;
 
 			$data = array();
 
 			$this->sort = array();
 
 			$map = array();
-			$map["fileas"] = $this->ab_properties['account'];
+			$map['fileas'] = $this->properties['account'];
 
 			// Parse incoming sort order
-			$this->parseSortOrder($action, $map, true, $this->ab_properties);
+			$this->parseSortOrder($action, $map, true);
 
-			if($paginationCharacter == "...")
-				$paginationCharacter = "";
+			if($paginationCharacter == '...')
+				$paginationCharacter = '';
 
 			if(!DISABLE_FULL_GAB || !empty($searchstring) || !empty($paginationCharacter)) {
-				$ab = $GLOBALS["mapisession"]->getAddressbook();
+				$ab = $GLOBALS['mapisession']->getAddressbook();
 
-				if (isset($action["entryid"]) && $action["entryid"] != "") {
-					$entryid = hex2bin($action["entryid"]);
+				if (!empty($action['entryid'])) {
+					$entryid = hex2bin($action['entryid']);
 				}else{
 					$entryid = mapi_ab_getdefaultdir($ab);
 				}
 
 				$dir = mapi_ab_openentry($ab,$entryid);
-				if (mapi_last_hresult()){
-					return false;
-				}
 
 				/**
-				 * @TODO: "All Address Lists" on IABContainer gives MAPI_E_INVALID_PARAMETER,
+				 * @TODO: 'All Address Lists' on IABContainer gives MAPI_E_INVALID_PARAMETER,
 				 * as it contains subfolders only. When #7344 is fixed, MAPI will return error here,
 				 * handle it here and return false.
 				 */
@@ -420,75 +206,104 @@
 				}
 				mapi_table_sort($table, $this->sort, TBL_BATCH);
 
-				// todo: fix paging stuff
-
-				$data["page"]["start"] = 0;
-				$data["page"]["rowcount"] = mapi_table_getrowcount($table);
-				$data["page"]["totalrowcount"] = $data["page"]["rowcount"];
-
-				$rows = mapi_table_queryrows($table, $this->ab_properties, 0, 0x7fffffff);
+				$rows = mapi_table_queryallrows($table, $this->properties);
 
+				$entryIdUtil = new EntryId();
 				for ($i = 0, $len = count($rows); $i < $len; $i++) {
-                    $user_data = $rows[$i];
-                    $item = array();
-                    $item["entryid"] = bin2hex($user_data[$this->ab_properties["entryid"]]);
-                    $item["display_name"] = $user_data[$this->ab_properties["display_name"]];
-                    $item["fileas"] = $user_data[$this->ab_properties["account"]];
-                    $item["object_type"] = $user_data[$this->ab_properties["object_type"]];
+					$user_data = $rows[$i];
 
-					switch($user_data[PR_DISPLAY_TYPE]){
-                        case DT_ORGANIZATION:
-							$item["display_type"] = $user_data[PR_DISPLAY_TYPE];
-							$item["display_type_ex"] = $user_data[PR_DISPLAY_TYPE_EX];
-                            $item["email_address"] = $user_data[$this->ab_properties["account"]];
-                            $item["message_flags"] = 0; // FIXME: we want companies to show "bold", so in fact this is some kind of a hack ;)
-							$item["address_type"] = "ZARAFA";
-							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
-                            break;
+					$item = array();
+					$item['entryid'] = bin2hex($user_data[$this->properties['entryid']]);
+					$item['display_name'] = $user_data[$this->properties['display_name']];
+					$item['object_type'] = $user_data[$this->properties['object_type']];
+					$item['display_type'] = $user_data[PR_DISPLAY_TYPE];
 
-                        case DT_DISTLIST:
-							$item["display_type"] = $user_data[PR_DISPLAY_TYPE];
-							$item["display_type_ex"] = $user_data[PR_DISPLAY_TYPE_EX];
-							$item["email_address"] = $user_data[$this->ab_properties["account"]];
-							$item["smtp_address"] = isset($user_data[$this->ab_properties["smtp_address"]]) ? $user_data[$this->ab_properties["smtp_address"]] : "";
-							$item["message_flags"] = 0; // FIXME: we want dist lists to show "bold", so in fact this is some kind of a hack ;)
-							$item["address_type"] = "ZARAFA";
-							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
+					// Test whether the GUID in the entryid is from the Contact Provider
+					if($entryIdUtil->hasContactProviderGUID( bin2hex($user_data[$this->properties['entryid']]) )){
+						// Use the original_display_name property to fill in the fileas column
+						$item['fileas'] = $user_data[$this->properties['original_display_name']];
+						$item['address_type'] = isset($user_data[$this->properties['address_type']]) ? $user_data[$this->properties['address_type']] : 'SMTP';
+
+						switch($user_data[PR_DISPLAY_TYPE]){
+							case DT_PRIVATE_DISTLIST:
+								$item['email_address'] = '';
+								break;
+							case DT_MAILUSER:
+							default:
+								$item['email_address'] = $user_data[$this->properties['email_address']];
+						}
+					} else {
+						// If display_type_ex is not set we can overwrite it with display_type
+						$item['display_type_ex'] = isset($user_data[PR_DISPLAY_TYPE_EX])?$user_data[PR_DISPLAY_TYPE_EX]:$user_data[PR_DISPLAY_TYPE];
+						$item['fileas'] = $item['display_name'];
+
+						switch($user_data[PR_DISPLAY_TYPE]){
+							case DT_ORGANIZATION:
+								$item['email_address'] = $user_data[$this->properties['account']];
+								$item['address_type'] = 'ZARAFA';
+								// The account property is used to fill in the fileas column
+								$item['fileas'] = $user_data[$this->properties['account']];
+								break;
+
+							case DT_DISTLIST:
+								// The account property is used to fill in the fileas column, private dislist does not have that
+								$item['fileas'] = $user_data[$this->properties['account']];
+							case DT_PRIVATE_DISTLIST:
+								$item['email_address'] = $user_data[$this->properties['account']];
+								$item['smtp_address'] = $user_data[$this->properties['smtp_address']];
+								$item['address_type'] = 'ZARAFA';
+								break;
+
+							case DT_MAILUSER:
+								// The account property is used to fill in the fileas column, remote mailuser does not have that
+								$item['fileas'] = $user_data[$this->properties['account']];
+							case DT_REMOTE_MAILUSER:
+							default:
+								$item['email_address'] = $user_data[$this->properties['email_address']];
+								$item['smtp_address'] = $user_data[$this->properties['smtp_address']];
+
+								$item['address_type'] = isset($user_data[$this->properties['address_type']]) ? $user_data[$this->properties['address_type']] : 'SMTP';
+								$item['department_name'] = isset($user_data[$this->properties['department_name']]) ? $user_data[$this->properties['department_name']] : '';
+								$item['office_telephone_number'] = isset($user_data[$this->properties['office_telephone_number']]) ? $user_data[$this->properties['office_telephone_number']] : '';
+								$item['office_location'] = isset($user_data[$this->properties['office_location']]) ? $user_data[$this->properties['office_location']] : '';
+								$item['primary_fax_number'] = isset($user_data[$this->properties['primary_fax_number']]) ? $user_data[$this->properties['primary_fax_number']] : '';
 							break;
+						}
+					}
 
-                        case DT_MAILUSER:
-                        default:
-							$item["display_type"] = $user_data[PR_DISPLAY_TYPE];
-							$item["display_type_ex"] = $user_data[PR_DISPLAY_TYPE_EX];
-							$item["email_address"] = $user_data[$this->ab_properties["email_address"]];
-							$item["smtp_address"] = $user_data[$this->ab_properties["smtp_address"]];
-							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
-							$item["address_type"] = isset($user_data[$this->ab_properties["address_type"]]) ? $user_data[$this->ab_properties["address_type"]] : "SMTP";
-							$item["message_flags"] = MSGFLAG_READ;	// FIXME: setting message_flags to read, to fix the view
-							$item["department_name"] = isset($user_data[$this->ab_properties["department_name"]]) ? $user_data[$this->ab_properties["department_name"]] : "";
-							$item["office_telephone_number"] = isset($user_data[$this->ab_properties["office_telephone_number"]]) ? $user_data[$this->ab_properties["office_telephone_number"]] : "";
-							$item["office_location"] = isset($user_data[$this->ab_properties["office_location"]]) ? $user_data[$this->ab_properties["office_location"]] : "";
-							$item["primary_fax_number"] = isset($user_data[$this->ab_properties["primary_fax_number"]]) ? $user_data[$this->ab_properties["primary_fax_number"]] : "";
-							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
+					if(!empty($user_data[$this->properties['search_key']])) {
+						$item['search_key'] = bin2hex($user_data[$this->properties['search_key']]);
+					} else {
+						// contacts folders are not returning search keys, this should be fixed in ZCP
+						// meanwhile this is a workaround, check ZCP-10814
+						// if search key is not passed then we will generate it
+						$email_address = '';
+						if(!empty($item['smtp_address'])) {
+							$email_address = $item['smtp_address'];
+						} else if(!empty($item['email_address'])) {
+							$email_address = $item['email_address'];
+						}
 
-							// Contacts from the GAL have email-address saved in smtp_address property.
-							if(trim($item["email_address"]) == "") {
-								$item["email_address"] = $item["smtp_address"];
-							}
-                            break;
-                    }
+						if(!empty($email_address)) {
+							$item['search_key'] = bin2hex(strtoupper($item['address_type']) . ':' . strtoupper($email_address)) . '\0';
+						}
+					}
 
-                    array_push($items, array("props" => $item));
-                    
-                }
-            } else {
-	           	// Provide clue that full GAB is disabled.
-            	$data = array_merge($data, array("disable_full_gab" => DISABLE_FULL_GAB));
-            }
-			$data = array_merge($data, array("item"=>$items));
+					array_push($items, array('props' => $item));
+				}
 
-			$this->addActionData("list", $data);
-			$GLOBALS["bus"]->addData($this->getResponseData());
+				// todo: fix paging stuff
+				$data['page']['start'] = 0;
+				$data['page']['rowcount'] = mapi_table_getrowcount($table);
+				$data['page']['totalrowcount'] = $data['page']['rowcount'];
+			} else {
+				// Provide clue that full GAB is disabled.
+				$data = array_merge($data, array('disable_full_gab' => DISABLE_FULL_GAB));
+			}
+			$data = array_merge($data, array('item'=>$items));
+
+			$this->addActionData('list', $data);
+			$GLOBALS['bus']->addData($this->getResponseData());
 
 			return true;
 		}
@@ -539,7 +354,7 @@
 					$hide_users = Array($hide_users);
 				}
 
-				if(in_array("non_security", $hide_users)) {
+				if(in_array('non_security', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_BITMASK,
 														Array(
@@ -551,7 +366,7 @@
 							);
 				}
 
-				if(in_array("room", $hide_users)) {
+				if(in_array('room', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -565,7 +380,7 @@
 							);
 				}
 
-				if(in_array("equipment", $hide_users)) {
+				if(in_array('equipment', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -579,7 +394,7 @@
 							);
 				}
 
-				if(in_array("active", $hide_users)) {
+				if(in_array('active', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -593,7 +408,7 @@
 							);
 				}
 
-				if(in_array("non_active", $hide_users)) {
+				if(in_array('non_active', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -607,7 +422,7 @@
 							);
 				}
 
-				if(in_array("contact", $hide_users)) {
+				if(in_array('contact', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -621,14 +436,14 @@
 							);
 				}
 
-				if(in_array("system", $hide_users)) {
+				if(in_array('system', $hide_users)) {
 					array_push($tempRestrictions, Array(
 													RES_CONTENT,
 														Array(
-															FUZZYLEVEL => FL_FULLSTRING,
+															FUZZYLEVEL => FL_FULLSTRING | FL_IGNORECASE,
 															ULPROPTAG => PR_ACCOUNT,
 															VALUE => Array(
-																PR_ACCOUNT => "SYSTEM"
+																PR_ACCOUNT => 'SYSTEM'
 															)
 														)
 												)
@@ -706,7 +521,17 @@
 																PR_DISPLAY_TYPE => DT_DISTLIST
 															)
 														)
-													)
+												),
+												Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE,
+															VALUE => Array(
+																PR_DISPLAY_TYPE => DT_PRIVATE_DISTLIST
+															)
+														)
+												)
 											)
 									);
 			} else if($hide_groups) {
@@ -717,7 +542,7 @@
 					$hide_groups = Array($hide_groups);
 				}
 
-				if(in_array("non_security", $hide_groups)) {
+				if(in_array('non_security', $hide_groups)) {
 					array_push($tempRestrictions, Array(
 													RES_BITMASK,
 														Array(
@@ -729,7 +554,7 @@
 							);
 				}
 
-				if(in_array("normal", $hide_groups)) {
+				if(in_array('normal', $hide_groups)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -743,7 +568,7 @@
 							);
 				}
 
-				if(in_array("security", $hide_groups)) {
+				if(in_array('security', $hide_groups)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -757,7 +582,7 @@
 							);
 				}
 
-				if(in_array("dynamic", $hide_groups)) {
+				if(in_array('dynamic', $hide_groups)) {
 					array_push($tempRestrictions, Array(
 													RES_PROPERTY,
 														Array(
@@ -771,14 +596,28 @@
 							);
 				}
 
-				if(in_array("everyone", $hide_groups)) {
+				if(in_array('distribution_list', $hide_groups)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_EQ,
+															ULPROPTAG => PR_DISPLAY_TYPE,
+															VALUE => Array(
+																PR_DISPLAY_TYPE => DT_PRIVATE_DISTLIST
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array('everyone', $hide_groups)) {
 					array_push($tempRestrictions, Array(
 													RES_CONTENT,
 														Array(
-															FUZZYLEVEL => FL_FULLSTRING,
+															FUZZYLEVEL => FL_FULLSTRING | FL_IGNORECASE,
 															ULPROPTAG => PR_ACCOUNT,
 															VALUE => Array(
-																PR_ACCOUNT => "Everyone"
+																PR_ACCOUNT => 'Everyone'
 															)
 														)
 													)
@@ -791,9 +630,12 @@
 											Array(
 												Array(
 													RES_AND,
+													Array(
 														Array(
+															RES_OR,
 															Array(
-																RES_PROPERTY,
+																Array(
+																	RES_PROPERTY,
 																	Array(
 																		RELOP => RELOP_EQ,
 																		ULPROPTAG => PR_DISPLAY_TYPE,
@@ -801,12 +643,24 @@
 																			PR_DISPLAY_TYPE => DT_DISTLIST
 																		)
 																	)
-															),
-															Array(
-																RES_OR,
-																$tempRestrictions					// all group restrictions
+																),
+																Array(
+																	RES_PROPERTY,
+																	Array(
+																		RELOP => RELOP_EQ,
+																		ULPROPTAG => PR_DISPLAY_TYPE,
+																		VALUE => Array(
+																			PR_DISPLAY_TYPE => DT_PRIVATE_DISTLIST
+																		)
+																	)
+																)
 															)
+														),
+														Array(
+															RES_OR,
+															$tempRestrictions     // all group restrictions
 														)
+													)
 												)
 											)
 										);
@@ -842,52 +696,23 @@
 
 		function getHierarchy($action)
 		{
-			$data = array();
-
-			$storeslist = false;
-			if (isset($action["contacts"])){
-				if (isset($action["contacts"]["stores"]["store"]) && !is_array($action["contacts"]["stores"]["store"])){
-					$action["contacts"]["stores"]["store"] = array($action["contacts"]["stores"]["store"]);
-				}
-				if (isset($action["contacts"]["stores"]["folder"]) && !is_array($action["contacts"]["stores"]["folder"])){
-					$action["contacts"]["stores"]["folder"] = array($action["contacts"]["stores"]["folder"]);
-				}
-				$storeslist = $action["contacts"]["stores"];
+			$hideContacts = false;
+			// Check if hide_contacts is set in the restriction
+			if(isset($action['restriction']) && isset($action['restriction']['hide_contacts'])){
+				$hideContacts = $action['restriction']['hide_contacts'];
 			}
-			
-			$folders = $GLOBALS["operations"]->getAddressbookHierarchy($storeslist);
 
-			$data = array( "item" => $folders );
-
-			$this->addActionData("list", $data);
-			$GLOBALS["bus"]->addData($this->getResponseData());
+			$folders = $GLOBALS['operations']->getAddressbookHierarchy($hideContacts);
+			$data = array( 'item' => $folders );
+			$this->addActionData('list', $data);
+			$GLOBALS['bus']->addData($this->getResponseData());
 
 			return true;
 		}
 
-
-		function expandGroup($entryid)
-		{
-			$result = array();
-			$group = mapi_ab_openentry($GLOBALS["mapisession"]->getAddressbook(), $entryid);
-			$table = mapi_folder_getcontentstable($group, MAPI_DEFERRED_ERRORS);
-			$items = mapi_table_queryallrows($table, $this->ab_properties);
-			foreach($items as $item){
-				if($item[$this->ab_properties["display_type"]] == DT_MAILUSER && isset($item[$this->ab_properties["smtp_address"]])) {
-					$result[] = array(
-							"entryid"=>bin2hex($item[$this->ab_properties["entryid"]]),
-							"fileas"=>$item[$this->ab_properties["account"]],
-							"display_name"=>$item[$this->ab_properties["display_name"]],
-							"address_type"=>$item[$this->ab_properties["address_type"]],
-							"email_address"=>$item[$this->ab_properties["smtp_address"]],
-						);
-				}
-			}
-			return $result;
-		}
-
 		/**
 		 * Function will return restriction used in GAB pagination.
+		 * @FIXME this function needs to be updated according to new changes
 		 * @param array $action the action data, sent by the client
 		 * @param string $actionType the action type, sent by the client
 		 * @return array paginationRestriction returns restriction used in pagination.
@@ -901,7 +726,7 @@
 
 				$paginationColumnProperties = array();
 				// Get Pagination column Properties.
-				if($actionType == "contacts") {
+				/*if($actionType == "contacts") {
 					array_push($paginationColumnProperties, $this->properties["fileas"]);
 					array_push($paginationColumnProperties, $this->properties["display_name"]);
 					array_push($paginationColumnProperties, $this->properties["email_address_1"]);
@@ -910,23 +735,23 @@
 					array_push($paginationColumnProperties, $this->properties["email_address_display_name_2"]);
 					array_push($paginationColumnProperties, $this->properties["email_address_3"]);
 					array_push($paginationColumnProperties, $this->properties["email_address_display_name_3"]);
-				} else if ($actionType == "globaladdressbook") {
-					array_push($paginationColumnProperties, $this->ab_properties["account"]);
-					array_push($paginationColumnProperties, $this->ab_properties["display_name"]);
-					array_push($paginationColumnProperties, $this->ab_properties["smtp_address"]);
-					array_push($paginationColumnProperties, $this->ab_properties["department_name"]);
-					array_push($paginationColumnProperties, $this->ab_properties["office_location"]);
-				}
+				} else if ($actionType == "globaladdressbook") {*/
+					array_push($paginationColumnProperties, $this->properties["account"]);
+					array_push($paginationColumnProperties, $this->properties["display_name"]);
+					array_push($paginationColumnProperties, $this->properties["smtp_address"]);
+					array_push($paginationColumnProperties, $this->properties["department_name"]);
+					array_push($paginationColumnProperties, $this->properties["office_location"]);
+				//}
 
 				// Get Pagination character.
-				$paginationCharacter = $action["restriction"]["pagination_character"];
+				$paginationCharacter = $action['restriction']['pagination_character'];
 				
 				// Create restriction according to paginationColumn
 				$restrictions = array();
 				foreach ($paginationColumnProperties as $paginationColumnProperty)
 				{
 					switch ($paginationCharacter){
-						case "123":
+						case '123':
 							array_push($restrictions,
 												array(
 														RES_AND,
@@ -935,9 +760,9 @@
 																RES_PROPERTY,
 																array(
 																	RELOP => RELOP_GE,
-																	ULPROPTAG =>  $paginationColumnProperty,
+																	ULPROPTAG => $paginationColumnProperty,
 																	VALUE => array(
-																		$paginationColumnProperty => "0"
+																		$paginationColumnProperty => '0'
 																	)
 																)
 															),
@@ -947,7 +772,7 @@
 																	RELOP => RELOP_LE,
 																	ULPROPTAG => $paginationColumnProperty,
 																	VALUE => array(
-																		$paginationColumnProperty => "9"
+																		$paginationColumnProperty => '9'
 																	)
 																)
 															)
@@ -956,14 +781,14 @@
 												);
 						break;
 
-						case "z":
+						case 'z':
 							array_push($restrictions,
 											array(
 												RES_PROPERTY,
 												array(RELOP => RELOP_GE,
 													ULPROPTAG => $paginationColumnProperty,
 													VALUE => array(
-														$paginationColumnProperty => "z" 
+														$paginationColumnProperty => 'z' 
 														)
 													)
 												)
@@ -979,7 +804,7 @@
 																	RES_PROPERTY,
 																	array(
 																		RELOP => RELOP_GE,
-																		ULPROPTAG =>  $paginationColumnProperty,
+																		ULPROPTAG => $paginationColumnProperty,
 																		VALUE => array(
 																			$paginationColumnProperty => $paginationCharacter
 																		)
