@@ -355,7 +355,7 @@
 
 				// Find current delegate and get permission.
 				foreach($grants as $id => $grant) {
-					if($GLOBALS["entryid"]->compareEntryIds(bin2hex($userEntryId), bin2hex($grant['userid']))) {
+					if($GLOBALS["entryid"]->compareABEntryIds(bin2hex($userEntryId), bin2hex($grant['userid']))) {
 						$delegateRights['rights_' . $folderName] = $grant['rights'];
 					}
 				}
@@ -407,7 +407,7 @@
 
 					// check if user exists in addresslist for rule
 					foreach($adrlist as $key => $user) {
-						if($GLOBALS["entryid"]->compareEntryIds(bin2hex($user[PR_ENTRYID]), bin2hex($userEntryId))) {
+						if($GLOBALS["entryid"]->compareABEntryIds(bin2hex($user[PR_ENTRYID]), bin2hex($userEntryId))) {
 							return true;
 						}
 					}
@@ -677,7 +677,7 @@
 			if(!empty($usersToRemove)) {
 				for($index = 0, $len = count($usersToRemove); $index < $len; $index++) {
 					for($index2 = 0, $len2 = count($users); $index2 < $len2; $index2++) {
-						if($GLOBALS["entryid"]->compareEntryIds(bin2hex($usersToRemove[$index][PR_ENTRYID]), bin2hex($users[$index2][PR_ENTRYID]))) {
+						if($GLOBALS["entryid"]->compareABEntryIds(bin2hex($usersToRemove[$index][PR_ENTRYID]), bin2hex($users[$index2][PR_ENTRYID]))) {
 							unset($users[$index]);
 							break;
 						}
@@ -693,7 +693,7 @@
 				// modify existing users
 				for($index = 0, $len = count($usersToAdd); $index < $len; $index++) {
 					for($index2 = 0, $len2 = count($users); $index2 < $len2; $index2++) {
-						if($GLOBALS["entryid"]->compareEntryIds(bin2hex($usersToAdd[$index][PR_ENTRYID]), bin2hex($users[$index2][PR_ENTRYID]))) {
+						if($GLOBALS["entryid"]->compareABEntryIds(bin2hex($usersToAdd[$index][PR_ENTRYID]), bin2hex($users[$index2][PR_ENTRYID]))) {
 							$users[$index2] = $usersToAdd[$index];
 							unset($usersToAdd[$index]);
 							break;
@@ -899,10 +899,12 @@
 		 * 
 		 * @param object $e Exception object
 		 * @param string $actionType the action type, sent by the client
+		 * @param MAPIobject $store Store object of the current user.
+		 * @param string $parententryid parent entryid of the message.
 		 * @param string $entryid entryid of the message/folder.
 		 * @param array $action the action data, sent by the client
 		 */
-		function handleException(&$e, $actionType = null, $entryid = null, $action = null)
+		function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null)
 		{
 			switch($actionType) {
 				case 'save':
@@ -916,7 +918,7 @@
 					break;
 			}
 
-			parent::handleException($e, $actionType, $entryid, $action);
+			parent::handleException($e, $actionType, $store, $parententryid, $entryid, $action);
 		}
 	}
 ?>
