@@ -36,19 +36,6 @@
 						$parententryid = $this->getActionParentEntryID($action);
 						$entryid = $this->getActionEntryID($action);
 
-						$overQouta = $this->checkOverQoutaRestriction($store, $actionType, $action);
-						if(!empty($overQouta)) {
-							if($overQouta == "quota_hard") {
-								throw new ZarafaException(_("The message store has exceeded its hard quota limit.") . "\n\n" .
-														  _("To reduce the amount of data in this message store, select some items that you no longer need, and permanently (SHIFT + DEL) delete them.")
-								);
-							} else if($overQouta == "quota_soft") {
-								throw new ZarafaException(_("The message store has exceeded its soft quota limit.") . "\n\n" .
-														  _("To reduce the amount of data in this message store, select some items that you no longer need, and permanently (SHIFT + DEL) delete them.")
-								);
-							}
-						}
-
 						switch($actionType)
 						{
 							case "open":
@@ -62,9 +49,6 @@
 									 * Supported actions:
 									 *   - acceptmeetingrequest: attendee has accepted mr
 									 *   - declineMeetingRequest: attendee has declined mr
-									 *   - cancelInvitation: organizer cancels already scheduled meeting
-									 *   - removeFromCalendar: attendee receives meeting cancellation and wants to remove item from calendar
-									 * switch-statement.
 									 */
 									if (isset($action["message_action"]) && isset($action["message_action"]["action_type"])) {
 										switch($action["message_action"]["action_type"])
@@ -108,10 +92,11 @@
 													$newProposedEndTime = isset($action["message_action"]["proposed_endtime"]) ? $action["message_action"]["proposed_endtime"] : false;
 
 													// We are accepting MR from preview-read-mail so set delete the actual mail flag.
-													$delete = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
+													$delete = $req->isMeetingRequest($originalMessageProps[PR_MESSAGE_CLASS]);
+
 													$req->doAccept($tentative, $sendResponse, $delete, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
 												} else {
-													$delete = $req->doDecline($sendResponse, $store, $basedate, $body);
+													$delete = $req->doDecline($sendResponse, $basedate, $body);
 												}
 
 												// Publish updated free/busy information
@@ -175,6 +160,13 @@
 									$subActionType = $action["message_action"]["action_type"];
 								}
 
+								/*
+								 * The "message_action" object has been set, check the action_type field for
+								 * the exact action which must be taken.
+								 * Supported actions:
+								 *   - cancelInvitation: organizer cancels already scheduled meeting
+								 *   - removeFromCalendar: attendee receives meeting cancellation and wants to remove item from calendar
+								 */
 								switch($subActionType)
 								{
 									case "removeFromCalendar":
@@ -190,6 +182,7 @@
 										break;
 
 									case "declineMeeting":
+										// @FIXME can we somehow merge declineMeeting and declineMeetingRequest sub actions?
 										$message = $GLOBALS["operations"]->openMessage($store, $entryid);
 										// @FIXME: 'basedate' should be moved, maybe either in 'props' or 'message_action'?
 										$basedate = (isset($action['basedate']) && !empty($action['basedate'])) ? $action['basedate'] : false;
@@ -203,7 +196,7 @@
 										} else {
 											$body = isset($action["props"]["body"]) ? $action["props"]["body"] : false;
 										}
-										$req->doDecline(true, $store, $basedate, $body);
+										$req->doDecline(true, $basedate, $body);
 
 										// Publish updated free/busy information
 										$GLOBALS["operations"]->publishFreeBusy($store);
@@ -226,9 +219,6 @@
 										break;
 								}
 								break;
-							case "read_flag":
-								$this->setReadFlag($store, $parententryid, $entryid, $action);
-								break;
 							case "checknames":
 								$this->checkNames($store, $action);
 								break;
@@ -237,10 +227,6 @@
 								$this->resolveConflict($store, $parententryid, $entryid, $action);
 								break;
 
-							case "attach_items":
-								$this->forwardMultipleItems($store, $parententryid, $action);
-								break;
-
 							case "reclaimownership":
 								$message = $GLOBALS["operations"]->openMessage($store, $entryid);
 								$tr = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
@@ -268,7 +254,7 @@
 								$this->handleUnknownActionType($actionType);
 						}
 					} catch (MAPIException $e) {
-						$this->processException($e, $actionType, null, $action);
+						$this->processException($e, $actionType, $store, $parententryid, $entryid, $action);
 					}
 				}
 			}
@@ -281,10 +267,12 @@
 		 * 
 		 * @param object $e Exception object
 		 * @param string $actionType the action type, sent by the client
+		 * @param MAPIobject $store Store object of message.
+		 * @param string $parententryid parent entryid of the message.
 		 * @param string $entryid entryid of the message.
 		 * @param array $action the action data, sent by the client
 		 */
-		function handleException(&$e, $actionType=null, $entryid=null, $action=null)
+		function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null)
 		{
 			if(is_null($e->displayMessage)) {
 				switch($actionType)
@@ -298,12 +286,14 @@
 
 					case "save":
 						if($e->getCode() == MAPI_E_NO_ACCESS) {
-							if (isset($action["message_action"]) && isset($action["message_action"]["action_type"])) {
+							if (!empty($action["message_action"]["action_type"])) {
 								switch($action["message_action"]["action_type"])
 								{
 									case "declineMeetingRequest":
+										$e->setDisplayMessage(_("You have insufficient privileges to decline this Meeting Request") . ".");
+										break;
 									case "acceptMeetingRequest":
-										$e->setDisplayMessage(_("Access Denied") . ".");
+										$e->setDisplayMessage(_("You have insufficient privileges to accept this Meeting Request") . ".");
 										break;
 									case "copy":
 										$e->setDisplayMessage(_("Could not copy message") . ".");
@@ -317,7 +307,9 @@
 							if(empty($e->displayMessage)) {
 								$e->setDisplayMessage(_("You have insufficient privileges to save items in this folder") . ".");
 							}
-						} else {
+						} else if($e->getCode() == MAPI_E_STORE_FULL) {
+							$e->setDisplayMessage($this->getOverQuotaMessage($store));
+						}else {
 							$e->setDisplayMessage(_("Could not save message") . ".");
 						}
 						break;
@@ -371,37 +363,7 @@
 				}
 			}
 
-			parent::handleException($e, $actionType, $entryid, $action);
-		}
-
-		/**
-		 * Function which sets selected messages as attachment to the item
-		 * @param object $store MAPI Message Store Object
-		 * @param string $parententryid entryid of the message
-		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure 
-		 */
-		function forwardMultipleItems($store, $parententryid, $action)
-		{
-			if($store){
-				if(isset($action["entryids"]) && $action["entryids"]){
-					
-					if(!is_array($action["entryids"])){
-						$action["entryids"] = array($action["entryids"]);
-					}
-
-					//add attach items to session variables
-					$attachments = $GLOBALS["operations"]->setAttachmentInSession($store, $action["entryids"], $action["dialog_attachments"]);
-				}
-
-				$data = array();
-				$data["item"] = array();
-				$data["item"]["parententryid"] = bin2hex($parententryid);
-				$data["item"]["attachments"] = array_merge($data["item"]["attachments"], $attachments);
-
-				$this->addActionData("attach_items", $data);
-				$GLOBALS["bus"]->addData($this->getResponseData());
-			}
+			parent::handleException($e, $actionType, $store, $parententryid, $entryid, $action);
 		}
 
 		/**
@@ -436,29 +398,11 @@
 			if(isset($data["item"]['props']["message_class"]) && strpos($data["item"]['props']["message_class"], "IPM.Schedule.Meeting") !== false) {
 				$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession(), $this->directBookingMeetingRequest);
 
-				$defaultCalendarId = $req->getDefaultFolderEntryID(PR_IPM_APPOINTMENT_ENTRYID);
-
-				if($GLOBALS["operations"]->checkFolderAccess($store, $defaultCalendarId)) {
+				try {
 					if($req->isMeetingRequestResponse()) {
-						// @FIXME do we need this check here? shouldn't meetingrequest class decide if its delegate mail or not?
 						if($req->isLocalOrganiser()) {
-							// We received a meeting request response, and we're the organiser
-							$apptProps = $req->processMeetingRequestResponse();
-						}else if(isset($data["item"]['props']['received_representing_name'])){
-							// We can also received a meeting request response, when we are delegate
-							$apptProps = $req->processMeetingRequestResponseAsDelegate();
-						}
-						mapi_savechanges($message);
-
-						if (isset($apptProps) && $apptProps) {
-							$data['item']['props'] = array_merge($data['item']['props'], array(
-								'appointment_entryid' => $apptProps['entryid'],
-								'appointment_store_entryid' => $apptProps['storeid'],
-								'appointment_parent_entryid' => $apptProps['parententryid'],
-								'appointment_basedate' => isset($apptProps['basedate']) && $apptProps['basedate'] ? $apptProps['basedate'] : null,
-								'appointment_updatecounter' => $apptProps['updatecounter'],
-								'meeting_updated' => $apptProps['meeting_updated']
-							));
+							// We received a meeting request response, and we're the delegate/organiser
+							$req->processMeetingRequestResponse();
 						}
 					} else if($req->isMeetingRequest()) {
 						if(!$req->isLocalOrganiser()) {
@@ -483,27 +427,37 @@
 
 							// Show user whether meeting request conflict with other appointment or not.
 							$meetingConflicts = $req->isMeetingConflicting();
+
 							/**
 							 * if $meetingConflicts is boolean and true then its a normal meeting.
 							 * if $meetingConflicts is integer then it indicates no of instances of a recurring meeting which conflicts with Calendar.
 							 */
 							if($meetingConflicts !== false) {
 								if ($meetingConflicts === true) {
-									$data['item']['props']['conflictinfo'] = _('Conflicts with another appointment on your Calendar.');
+									$data['item']['props']['conflictinfo'] = _('Conflicts with another appointment.');
 								} else {
-									$data['item']['props']['conflictinfo'] = sprintf(ngettext('%s occurrence of this recurring appointment conflicts with other appointment on your Calendar.', '%s occurrences of this recurring appointment conflicts with other appointments on your Calendar.', $meetingConflicts), $meetingConflicts);
+									$data['item']['props']['conflictinfo'] = sprintf(ngettext('%s occurrence of this recurring appointment conflicts with other appointment.', '%s occurrences of this recurring appointment conflicts with other appointments.', $meetingConflicts), $meetingConflicts);
 								}
 							}
 						}
 					} else if($req->isMeetingCancellation()) {
-						if(!$req->isLocalOrganiser()) {
-							$req->processMeetingCancellation();
-						}
+						$req->processMeetingCancellation();
 					}
-					
-					if(!$req->isInCalendar()) {
+
+					if($req->isInCalendar()) {
+						$calendarItemProps = $this->getCalendarItemProps($req);
+						if (!empty($calendarItemProps)) {
+							$data['item']['props'] = array_merge($data['item']['props'], $calendarItemProps);
+						}
+					} else {
 						$data['item']['props']['appointment_not_found'] = true;
 					}
+				} catch (MAPIException $e) {
+					// if quota is exceded or or we don't have permission to write in calendar folder than ignore the exception.
+					if($e->getCode() !== MAPI_E_STORE_FULL && $e->getCode() !== MAPI_E_NO_ACCESS) {
+						// re-throw the exception if it is not one of quota/calendar permission.
+						throw $e;
+					}
 				}
 			}
 
@@ -651,9 +605,10 @@
 				$msg_action = isset($action['message_action']) ? $action['message_action'] : false;
 				$result = $GLOBALS["operations"]->setMessageFlag($store, $entryid, $flags, $msg_action, $props);
 
-				if($result) {
+				if ($result) {
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $props);
 				}
+				$this->sendFeedback($result);
 			}
 		}
 				
@@ -828,5 +783,51 @@
 				$this->sendFeedback($result, array());
 			}
 		}
+
+		/**
+		 * Function returns correspondent calendar item's properties attached 
+		 * with the meeting request/response/cancellation.
+		 * @param Meetingrequest $meetingRequestObject the meeting request object
+		 * using which function will fetch meeting request properties and return them.
+		 */
+		function getCalendarItemProps($meetingRequestObject)
+		{
+			$calendarItem = $meetingRequestObject->getCorrespondentCalendarItem();
+			if ($calendarItem !== false) {
+				$calendarItemProps = mapi_getprops($calendarItem, array(PR_STORE_ENTRYID, PR_PARENT_ENTRYID, PR_ENTRYID, $meetingRequestObject->proptags['updatecounter'], $meetingRequestObject->proptags['goid']));
+
+				// Store calendar item's necessary properties in props array.
+				$props['appointment_store_entryid'] = bin2hex($calendarItemProps[PR_STORE_ENTRYID]);
+				$props['appointment_parent_entryid'] = bin2hex($calendarItemProps[PR_PARENT_ENTRYID]);
+				$props['appointment_entryid'] = bin2hex($calendarItemProps[PR_ENTRYID]);
+
+				$props['appointment_updatecounter'] = isset($calendarItemProps[$meetingRequestObject->proptags['updatecounter']]) ? $calendarItemProps[$meetingRequestObject->proptags['updatecounter']] : 0;
+
+				$messageProps = mapi_getprops($meetingRequestObject->message, array($meetingRequestObject->proptags['goid']));
+
+				$basedate = $meetingRequestObject->getBasedateFromGlobalID($messageProps[$meetingRequestObject->proptags['goid']]);
+
+				if($basedate) {
+					$props['appointment_basedate'] = $basedate;
+
+					// if basedate is provided then it is exception, so get update counter of the exceotion
+					$exception = $meetingRequestObject->getExceptionItem($calendarItem, $basedate);
+
+					if($exception !== false) {
+						// we are able to find the exception then get updatecounter
+						$exceptionProps = mapi_getprops($exception, array($meetingRequestObject->proptags['updatecounter']));
+						$props['appointment_updatecounter'] = isset($exceptionProps[$meetingRequestObject->proptags['updatecounter']]) ? $exceptionProps[$meetingRequestObject->proptags['updatecounter']] : 0;
+					}
+				}
+
+				if($meetingRequestObject->isMeetingRequestResponse()) {
+					$data['item']['props']['meeting_updated'] = $meetingRequestObject->isMeetingUpdated(true, $basedate);
+				}
+
+				return $props;
+			}
+
+			return false;
+		}
 	}
 ?>
