@@ -78,7 +78,7 @@
 
 			$this->sort = array();
 			
-			parent::Module($id, $data, $events);
+			parent::Module($id, $data);
 		}
 		
 		/**
@@ -105,7 +105,7 @@
 								$this->handleUnknownActionType($actionType);
 						}
 					} catch (MAPIException $e) {
-						$this->processException($e, $actionType);
+						$this->processException($e, $actionType, $store, $parententryid, $entryid, $action);
 					}
 				}
 			}
@@ -118,10 +118,12 @@
 		 * 
 		 * @param object $e Exception object
 		 * @param string $actionType the action type, sent by the client
+		 * @param MAPIobject $store Store object of the current user.
+		 * @param string $parententryid parent entryid of the message.
 		 * @param string $entryid entryid of the message/folder.
 		 * @param array $action the action data, sent by the client
 		 */
-		function handleException(&$e, $actionType=null, $entryid=null, $action=null)
+		function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null)
 		{
 			if (is_null($e->displayMessage)) {
 				switch($actionType) {
@@ -135,7 +137,7 @@
 				}
 			}
 
-			parent::handleException($e, $actionType, $entryid, $action);
+			parent::handleException($e, $actionType, $store, $parententryid, $entryid, $action);
 		}
 
 		/**
@@ -157,33 +159,37 @@
 				// Sort
 				$this->parseSortOrder($action, null, true);
 
-				// Create the data array, which will be send back to the client
-				$data = array();
-
-				// filter out extra properties that are not needed in list view
-				$properties = $this->properties;
-				//$properties = $this->filterOutExtraProperties();
-
 				// @TODO add implementation of https://jira.zarafa.com/browse/ZCP-9325
 
 				// Get the table and merge the arrays
-				$items = $GLOBALS["operations"]->getTable($store, $entryid, $properties, $this->sort, $this->start, false, $this->searchRestriction);
+				$data = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction);
+
+				// Open the folder.
+				$folder = mapi_msgstore_openentry($store, $entryid);
+				$data["folder"] = array();
+				
+				// Obtain some statistics from the folder contents
+				$contentcount = mapi_getprops($folder, array(PR_CONTENT_COUNT, PR_CONTENT_UNREAD));
+				if (isset($contentcount[PR_CONTENT_COUNT])) {
+					$data["folder"]["content_count"] = $contentcount[PR_CONTENT_COUNT];
+				}
+				if (isset($contentcount[PR_CONTENT_UNREAD])) {
+					$data["folder"]["content_unread"] = $contentcount[PR_CONTENT_UNREAD];
+				}
 
 				// Disable private items
-				for($index = 0, $len = count($items["item"]); $index < $len; $index++) {
-					$items["item"][$index] = $this->processPrivateItem($items["item"][$index]);
+				for($index = 0, $len = count($data["item"]); $index < $len; $index++) {
+					$data["item"][$index] = $this->processPrivateItem($data["item"][$index]);
 
-					if(empty($items["item"][$index])) {
+					if(empty($data["item"][$index])) {
 						// remove empty results from data
-						unset($items["item"][$index]);
+						unset($data["item"][$index]);
 					}
 				}
 
 				// unset will remove the value but will not regenerate array keys, so we need to
 				// do it here
-				$items["item"] = array_values($items["item"]);
-
-				$data = array_merge($data, $items);
+				$data["item"] = array_values($data["item"]);
 
 				$this->addActionData("list", $data);
 				$GLOBALS["bus"]->addData($this->getResponseData());
@@ -282,12 +288,8 @@
 				sleep(1);
 			}
 
-			// filter out extra properties that are not needed in list view
-			$properties = $this->properties;
-			//$properties = $this->filterOutExtraProperties();
-
 			// Get the table and merge the arrays
-			$table = $GLOBALS["operations"]->getTable($store, hex2bin($this->searchFolderEntryId), $properties, $this->sort, $this->start);
+			$table = $GLOBALS["operations"]->getTable($store, hex2bin($this->searchFolderEntryId), $this->properties, $this->sort, $this->start);
 			$data = array_merge($data, $table);
 
 			// remember which entryid's are send to the client
@@ -332,10 +334,10 @@
 			}
 
 			$listData = array();
-			$folder = mapi_msgstore_openentry($store, $entryid);
-			$searchResult = mapi_folder_getsearchcriteria($folder);
+			$searchFolder = mapi_msgstore_openentry($store, $entryid);
+			$searchResult = mapi_folder_getsearchcriteria($searchFolder);
 			$searchState = $searchResult["searchstate"];
-			$table = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
+			$table = mapi_folder_getcontentstable($searchFolder, MAPI_DEFERRED_ERRORS);
 
 			if(is_array($this->sort) && !empty($this->sort)) {
 				// this sorting will be done on currently fetched results, not all results
@@ -343,7 +345,7 @@
 				mapi_table_sort($table, $this->sort, TBL_BATCH);
 			}
 
-			$rowCount = $GLOBALS["settings"]->get("global/rowcount", 50);
+			$rowCount = 50; // FIXME: $GLOBALS["settings"]->get("global/rowcount", 50);
 
 			$searchResults = array();
 			$entryid = bin2hex($entryid);
@@ -358,10 +360,6 @@
 			if($numberOfResults < $rowCount) {
 				$items = mapi_table_queryallrows($table, array(PR_ENTRYID, PR_LAST_MODIFICATION_TIME));
 
-				// filter out extra properties that are not needed in list view
-				$properties = $this->properties;
-				//$properties = $this->filterOutExtraProperties();
-
 				foreach($items as $props) {
 					$sendItemToClient = false;
 
@@ -383,7 +381,7 @@
 					if($sendItemToClient) {
 						// only get primitive properties, no need to get body, attachments or recipient information
 						$message = $GLOBALS["operations"]->openMessage($store, $props[PR_ENTRYID]);
-						array_push($listData, $GLOBALS["operations"]->getProps($store, $message, $properties));
+						array_push($listData, $GLOBALS["operations"]->getProps($store, $message, $this->properties));
 
 						// store entryid => last_modification_time mapping
 						$searchResults[bin2hex($props[PR_ENTRYID])] = $props[PR_LAST_MODIFICATION_TIME];
@@ -704,22 +702,6 @@
 			}
 		}
 
-		/**
-		 * Function is used to filter out properties which aren't usefull in the listview and we should
-		 * remove it when getting listview data, this function gives us performance benefit of sending less data
-		 * in listview because sending properties like body, message_transport_headers in list view can increase
-		 * the response data a lot.
-		 * We don't want to store filtered properties in the module object because module object should always
-		 * have list of all properties.
-		 * this function is used as a placeholder here, child functions can override this function to filter
-		 * properties based on its own logic.
-		 * @return {Object} filtered properties that will be used to get data for list view.
-		 */
-		function filterOutExtraProperties()
-		{
-			return $this->properties;
-		}
-
 		/**
 		 * Function which create a task from a mail by copying its subject and body.
 		 * @param object $store MAPI Message Store Object
@@ -729,12 +711,12 @@
 		function createTaskFromMail($store, $entryid)
 		{
 			if($store && $entryid) {
-				$inbox = mapi_msgstore_getreceivefolder($store);
-				$inboxprops = mapi_getprops($inbox, Array(PR_IPM_TASK_ENTRYID, PR_STORE_ENTRYID));
-				$parententryid = bin2hex($inboxprops[PR_IPM_TASK_ENTRYID]);
+				$root = mapi_msgstore_openentry($store, null);
+				$rootprops = mapi_getprops($root, Array(PR_IPM_TASK_ENTRYID, PR_STORE_ENTRYID));
+				$parententryid = bin2hex($rootprops[PR_IPM_TASK_ENTRYID]);
 
 				// open the userstore to fetch the name of the owner of the store.
-				$userstore = mapi_openmsgstore($GLOBALS["mapisession"]->getSession(),$inboxprops[PR_STORE_ENTRYID]);
+				$userstore = mapi_openmsgstore($GLOBALS["mapisession"]->getSession(),$rootprops[PR_STORE_ENTRYID]);
 				$userstoreprops = mapi_getprops($userstore, Array(PR_MAILBOX_OWNER_NAME));
 
 				// open the mail to fetch the subject, body and importance.
@@ -765,112 +747,6 @@
 			}
 		}
 
-		/**
-		 * If an event elsewhere has occurred, it enters in this methode. This method
-		 * executes one ore more actions, depends on the event.
-		 * @param int $event Event.
-		 * @param string $entryid Entryid.
-		 * @param array $data array of data.
-		 */
-		function update($event, $entryid, $props)
-		{
-			$this->reset();
-
-			switch($event)
-			{
-				case TABLE_SAVE:
-					$data = array();
-
-					if(isset($props[PR_STORE_ENTRYID])) {
-						$store = $GLOBALS["mapisession"]->openMessageStore($props[PR_STORE_ENTRYID]);
-						
-						if(isset($props[PR_ENTRYID])) {
-							$data = $GLOBALS["operations"]->getMessageProps($store, $GLOBALS["operations"]->openMessage($store, $props[PR_ENTRYID]), $this->properties);
-							$this->addNotificationActionData("update", array( "item" => array($data) ));
-						} else if (isset($props[PR_PARENT_ENTRYID])) {
-							// An object was created inside this folder for which we don't know the entryid
-							// this can happen when we copy or move a message. Just tell the javascript that
-							// this folder has a new object.
-							$folder = mapi_msgstore_openentry($store, $props[PR_PARENT_ENTRYID]);
-							$folderProps = mapi_getprops($folder, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID, PR_CONTENT_COUNT, PR_CONTENT_UNREAD, PR_DISPLAY_NAME));
-
-							$data = array(
-								"item" => array(
-									array(
-										"content_count" => $folderProps[PR_CONTENT_COUNT],
-										"content_unread" => $folderProps[PR_CONTENT_UNREAD],
-										// Add store_entryid,entryid of folder and display_name of folder 
-										// to JSON data in order to refresh the list.
-										"store_entryid" => bin2hex($folderProps[PR_STORE_ENTRYID]),
-										"parent_entryid" => bin2hex($folderProps[PR_PARENT_ENTRYID]),
-										"entryid" => bin2hex($folderProps[PR_ENTRYID]),
-										"display_name" => $folderProps[PR_DISPLAY_NAME]
-									)
-								)
-							);
-
-							$this->addNotificationActionData("newobject", $data);
-						}
-					}
-					break;
-				case TABLE_DELETE:
-					// When user has used searchfolder the entryID of that folder should be used.
-					if(!$this->searchFolderList){
-						$folderEntryID = (isset($props[PR_PARENT_ENTRYID]))?$props[PR_PARENT_ENTRYID]:false;
-					}else{
-						$folderEntryID = (isset($this->searchFolderEntryId))?hex2bin($this->searchFolderEntryId):false;
-					}
-
-					if(isset($props[PR_ENTRYID]) && $folderEntryID) {
-						// Get items, which are shown under the table.
-						$store = $GLOBALS["mapisession"]->openMessageStore($props[PR_STORE_ENTRYID]);
-						
-						$deletedrows = 1;
-						if(is_array($props[PR_ENTRYID])) {
-							$deletedrows = count($props[PR_ENTRYID]);
-						}
-
-						$newItemsStart = ($this->start + $GLOBALS["settings"]->get("global/rowcount", 50)) - $deletedrows;
-						$newItems = $GLOBALS["operations"]->getTable($store, $folderEntryID, $this->properties, $this->sort, $newItemsStart, $deletedrows, $this->searchRestriction);
-						
-						if(!empty($newItems["item"])) {
-							$data = array();
-							$data["delete"] = 1;
-							if($this->searchFolderList){
-								// @FIXME do we need this attribute?
-								//$data["attributes"] = array("type" => "item", "searchfolder" => $this->searchFolderEntryId);
-							}
-							$data["item"] = $newItems["item"];
-
-							$this->addNotificationActionData("update", array( "item" => array($data) ));
-						}
-						
-						$data = array();
-						$data["page"] = $newItems["page"];
-						$data["page"]["start"] = $this->start;
-						$data["page"]["rowcount"] = $GLOBALS["settings"]->get("global/rowcount", 50);
-						$data["parent_entryid"] = bin2hex($folderEntryID);
-						
-						if(is_array($props[PR_ENTRYID])) {
-							$data["entryid"] = array();
-							
-							foreach($props[PR_ENTRYID] as $entryid)
-							{
-								array_push($data["entryid"], bin2hex($entryid));
-							}
-						} else {
-							$data["entryid"] = bin2hex($props[PR_ENTRYID]);
-						}
-
-						$this->addNotificationActionData("delete", array( "item" => array($data) ));
-					}
-					break;
-			}
-
-			$GLOBALS["bus"]->addData($this->getNotificationResponseData());
-			$this->responseNotificationData = array();
-		}
-
 		/**
 		 * Function which gets the delegation details from localfreebusy folder to use in
 		 * processPrivateItems function.
